@@ -33,16 +33,17 @@
 
 int locate_font(const char *family, int italic, int bold, char *path, int max_path_length);
 FontSettings locate_font_with_features(const char *family, int italic, int bold);
+FontSettings2 locate_font_with_features2(const char *family, double italic, double weight, double width, const int* axes, const int* coords, int n_axes);
 
 [[cpp11::register]]
-cpp11::list match_font_c(cpp11::strings family, cpp11::logicals italic, 
+cpp11::list match_font_c(cpp11::strings family, cpp11::logicals italic,
                          cpp11::logicals bold);
 
 [[cpp11::register]]
-cpp11::writable::data_frame locate_fonts_c(cpp11::strings family, 
-                                           cpp11::logicals italic, 
-                                           cpp11::integers weight, 
-                                           cpp11::integers width);
+cpp11::writable::data_frame locate_fonts_c(cpp11::strings family,
+                                           cpp11::doubles italic,
+                                           cpp11::doubles weight,
+                                           cpp11::doubles width);
 
 [[cpp11::register]]
 cpp11::writable::data_frame system_fonts_c();
