@@ -1,23 +1,40 @@
-#ifndef SFUTILS_H
-#define SFUTILS_H
+#pragma once
 
 #include <cstring>
 #include <cctype>
 #include <cstdint>
 #include <vector>
+#include <exception>
+#include <algorithm>
 
-#define R_NO_REMAP
+#include <cpp11/protect.hpp>
 
-#include <Rinternals.h>
-
-// Define a C++ try-catch macro to guard C++ calls
-#define BEGIN_CPP try {
-
-#define END_CPP                                                                \
-}                                                                              \
-catch (std::exception & e) {                                                   \
-  Rf_error("C++ exception: %s", e.what());                                     \
+#define BEGIN_CPP                 \
+SEXP err = R_NilValue;            \
+const size_t ERROR_SIZE = 8192;   \
+char buf[ERROR_SIZE] = "";        \
+try {
+#define END_CPP                                                \
 }                                                              \
+catch (cpp11::unwind_exception & e) {                          \
+  err = e.token;                                               \
+}                                                              \
+catch (std::exception & e) {                                   \
+  strncpy(buf, e.what(), ERROR_SIZE - 1);                      \
+}                                                              \
+catch (...) {                                                  \
+  strncpy(buf, "C++ error (unknown cause)", ERROR_SIZE - 1);   \
+}                                                              \
+if (buf[0] != '\0') {                                          \
+  Rf_error("%s", buf);                                         \
+} else if (err != R_NilValue) {                                \
+  R_ContinueUnwind(err);                                                 \
+}
+
+const static long WGHT_TAG = 2003265652;
+const static long WDTH_TAG = 2003072104;
+const static long ITAL_TAG = 1769234796;
+const static double FIXED_MOD = 65536.0;
 
 inline bool strcmp_no_case(const char * A, const char * B) {
   if (A == NULL && B == NULL) return true;
@@ -31,6 +48,8 @@ inline bool strcmp_no_case(const char * A, const char * B) {
   return true;
 }
 
+
+
 /*
  Basic UTF-8 manipulation routines
  by Jeff Bezanson
@@ -142,4 +161,15 @@ public:
   }
 };
 
-#endif
+inline int axis_to_tag(std::string axis) {
+  std::reverse(axis.begin(), axis.end());
+  const int *tag = reinterpret_cast<const int *>(axis.c_str());
+  return *tag;
+}
+
+inline std::string tag_to_axis(int tag) {
+  const char *axis = reinterpret_cast<const char *>(&tag);
+  std::string axis2(axis, 4);
+  std::reverse(axis2.begin(), axis2.end());
+  return axis2;
+}
